@@ -574,7 +574,7 @@ class AttrSpec(object):
                 flags |= _FG_HIGH_COLOR
             # _parse_color_*() return None for unrecognised colors
             if scolor is None:
-                raise AttrSpecError(("Unrecognised color specification %s" +
+                raise AttrSpecError(("Unrecognised color specification %s " +
                     "in foreground (%s)") % (repr(part), repr(foreground)))
             if color is not None:
                 raise AttrSpecError(("More than one color given for " +
@@ -646,6 +646,13 @@ class AttrSpec(object):
         else:
             return vals + _COLOR_VALUES_256[self.background_number]
 
+    def __eq__(self, other):
+        return isinstance(other, AttrSpec) and self._value == other._value
+
+    def __ne__(self, other):
+        return not self == other
+
+    __hash__ = object.__hash__
 
 
 class RealTerminal(object):
